Processor.processor.Listener
============================

.. currentmodule:: Processor.processor

.. autoclass:: Listener

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~Listener.__init__
      ~Listener.on_before_message
      ~Listener.on_connected
      ~Listener.on_connecting
      ~Listener.on_disconnected
      ~Listener.on_disconnecting
      ~Listener.on_error
      ~Listener.on_heartbeat
      ~Listener.on_heartbeat_timeout
      ~Listener.on_message
      ~Listener.on_receipt
      ~Listener.on_receiver_loop_completed
      ~Listener.on_send
   
   

   
   
   